@@ -25,7 +25,7 @@
 #include <libxnee/xnee.h>
 #include <semaphore.h>
 
-
+#ifdef XNEE_USE_SEMAPHORES
 int 
 xnee_sem_init(xnee_data *xd, sem_t *sem, int shared, int val);
 
@@ -40,7 +40,19 @@ xnee_sem_post(xnee_data *xd, sem_t *sem);
 
 int 
 xnee_sem_destroy(xnee_data *xd, sem_t *sem);
+#else
 
+#define xnee_sem_init(xd, sem, shared, val) 
+
+#define xnee_sem_wait(xd, sem) 
+
+#define xnee_sem_trywait(xd, sem) 
+
+#define xnee_sem_post(xd, sem) 
+
+#define xnee_sem_destroy(xd, sem) 
+
+#endif /* XNEE_USE_SEMAPHORES*/
 
 #define XNEE_BUFFER_SEM_INIT    
 #define XNEE_BUFFER_SEM_GET      
